A Cartesian coordinate system that adds sensible
guides to axes in a geom_hourglass() layer. It is added automatically
to geom_hourglass(). There is no need to explicitly add it to a ggplot,
unless you wish to tweak the coordinate system.
CoordHourglasscoord_hourglass(
xlim = NULL,
ylim = NULL,
expand = TRUE,
default = FALSE,
clip = "on",
date_labels = "%H:%M",
layer = NULL,
...
)
Returns a ggproto object inheriting from coord_cartesian().
An object of class CoordHourglass (inherits from CoordCartesian, Coord, ggproto, gg) of length 3.
Limits for the x and y axes.
If TRUE, the default, adds a small expansion factor to
the limits to ensure that data and axes don't overlap. If FALSE,
limits are taken exactly from the data or xlim/ylim.
Is this the default coordinate system? If FALSE (the default),
then replacing this coordinate system with another one creates a message alerting
the user that the coordinate system is being replaced. If TRUE, that warning
is suppressed.
Should drawing be clipped to the extent of the plot panel? A
setting of "on" (the default) means yes, and a setting of "off"
means no. In most cases, the default of "on" should not be changed,
as setting clip = "off" can cause unexpected results. It allows
drawing of data points anywhere on the plot, including in the plot margins. If
limits are set via xlim and ylim and some data points fall outside those
limits, then those data points may show up in places such as the axes, the
legend, the plot title, or the plot margins.
Formating string for formatting the time
labels on the axis. By default it is "%H:%M".
This argument allows you to pass the hourglass layer
to which the coordinate system should be applied. It is used to
derive the orientation of the plot. By default it is NULL and
an attempt is made to derive the orientation of the plot from its
axes scales.
Arguments passed as extra params to ggplot2::layer()
Pepijn de Vries