Learn R Programming

gghourglass (version 0.0.3)

gghourglass-package: gghourglass: Plot Records per Time of Day

Description

logo

Splits date and time of day components from continuous 'datetime' objects, then plots them using grammar of graphics ('ggplot2'). Plots can also be decorated with solar cycle information (e.g., sunset, sunrise, etc.). This is useful for visualising data that are associated with the solar cycle.

Arguments

Author

Maintainer: Pepijn de Vries pepijn.devries@outlook.com (ORCID)

Other contributors:

  • Sander Lagerveld (ORCID) [data contributor]

See Also