uses_dst: Test if datetime object potentially uses daylight saving time
Description
Function to check if a datetime object potentially uses daylight
saving time. It is not the same as lubridate::dst(), which will
determine if daylight saving time is set for the requested date.
Usage
uses_dst(x)
Value
Returns a logical value indicating of the time zone
used by the datetime object potentially uses daylight saving time.